==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/reef/dialogs_pl.lua <==

dialogId("uts-m-otresy", "font_small", "My goodness, the impact created cave-in!")
dialogStr("A niech to, uderzenie spowodowało zawał!")


dialogId("uts-v-projet0", "font_big", "I can`t go through this cave-in, we have to find another exit.")
dialogStr("Nie przepłynę przez ten zawał. Musimy znaleźć inne wyjście.")


dialogId("uts-v-projet1", "font_big", "This is not the way.")
dialogStr("Tędy się nie przecisnę.")


dialogId("uts-v-sam", "font_big", "I won`t make it alone.")
dialogStr("Sam nie dam rady.")


dialogId("uts-m-lastura", "font_small", "I probably should have had lifted that shell first.")
dialogStr("Chyba powinnam była najpierw podnieść tę muszlę...")


dialogId("uts-v-poradi", "font_big", "Maybe we have to switch these objects.")
dialogStr("Może powinniśmy zamienić te przedmioty miejscami?")


dialogId("uts-m-matrace", "font_small", "A mattress. The best thing you can get under water.")
dialogStr("Materac. Najlepsze, co możesz znaleźć pod wodą.")


dialogId("uts-m-snek", "font_small", "Now we can drop the snail on the mattress.")
dialogStr("Teraz możemy zrzucić ślimaka na materac.")


dialogId("uts-m-nezvedneme", "font_small", "It will be difficult to pick up that snail from there.")
dialogStr("Już tego ślimaka stamtąd nie wyciągniemy.")


dialogId("uts-v-konecne", "font_big", "Finally, it`s there.")
dialogStr("W końcu jest.")


dialogId("uts-m-chudak", "font_small", "The poor snail...")
dialogStr("Biedny ślimaczek...")


dialogId("uts-v-koraly", "font_big", "We should search the coral reefs.")
dialogStr("Powinniśmy przeszukać rafę.")


dialogId("uts-m-tvorove", "font_small", "There are going to be many interesting beings to investigate there.")
dialogStr("Tam z pewnością kryje się mnóstwo ciekawych stworzeń.")


dialogId("uts-v-mikroskop", "font_big", "Don`t we need a microscope to investigate corals?")
dialogStr("Nie potrzebujemy przypadkiem mikroskopu, aby zbadać korale?")


dialogId("uts-m-zivocich", "font_small", "Yes, they are small. But there can be other life forms.")
dialogStr("No, małe są. Ale mogą tam być i inne formy życia.")


dialogId("uts-m-zelvy", "font_small", "Coral turtles, for example.")
dialogStr("Na przykład żółwie koralowe.")


dialogId("uts-m-batyskaf", "font_small", "And moreover I have a suspicion that there's a microscope in a bathyscaph.")
dialogStr("Poza tym wydaje mi się, że mikroskop może być w takim jednym batyskafie...")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/reef/dialogs_pl.lua <==

dialogId("uts-m-otresy", "font_small", "My goodness, the impact created cave-in!")
dialogStr("A niech to, uderzenie spowodowało zawał!")


dialogId("uts-v-projet0", "font_big", "I can’t go through this cave-in, we have to find another exit.")
dialogStr("Nie przepłynę przez ten zawał. Musimy znaleźć inne wyjście.")


dialogId("uts-v-projet1", "font_big", "This is not the way.")
dialogStr("Tędy się nie przecisnę.")


dialogId("uts-v-sam", "font_big", "I won’t make it alone.")
dialogStr("Sam nie dam rady.")


dialogId("uts-m-lastura", "font_small", "I probably should have had lifted that shell first.")
dialogStr("Chyba powinnam była najpierw podnieść tę muszlę...")


dialogId("uts-v-poradi", "font_big", "Maybe we have to switch these objects.")
dialogStr("Może powinniśmy zamienić te przedmioty miejscami?")


dialogId("uts-m-matrace", "font_small", "A mattress. The best thing you can get under water.")
dialogStr("Materac. Najlepsze, co możesz znaleźć pod wodą.")


dialogId("uts-m-snek", "font_small", "Now we can drop the snail on the mattress.")
dialogStr("Teraz możemy zrzucić ślimaka na materac.")


dialogId("uts-m-nezvedneme", "font_small", "It will be difficult to pick up that snail from there.")
dialogStr("Już tego ślimaka stamtąd nie wyciągniemy.")


dialogId("uts-v-konecne", "font_big", "Finally, it’s there.")
dialogStr("W końcu jest.")


dialogId("uts-m-chudak", "font_small", "The poor snail...")
dialogStr("Biedny ślimaczek...")


dialogId("uts-v-koraly", "font_big", "We should search the coral reefs.")
dialogStr("Powinniśmy przeszukać rafę.")


dialogId("uts-m-tvorove", "font_small", "There are going to be many interesting beings to investigate there.")
dialogStr("Tam z pewnością kryje się mnóstwo ciekawych stworzeń.")


dialogId("uts-v-mikroskop", "font_big", "Don’t we need a microscope to investigate corals?")
dialogStr("Nie potrzebujemy przypadkiem mikroskopu, aby zbadać korale?")


dialogId("uts-m-zivocich", "font_small", "Yes, they are small. But there can be other life forms.")
dialogStr("No, małe są. Ale mogą tam być i inne formy życia.")


dialogId("uts-m-zelvy", "font_small", "Coral turtles, for example.")
dialogStr("Na przykład żółwie koralowe.")


dialogId("uts-m-batyskaf", "font_small", "And moreover I have a suspicion that there's a microscope in a bathyscaph.")
dialogStr("Poza tym wydaje mi się, że mikroskop może być w takim jednym batyskafie...")
